@@ -40,3 +40,13 @@ split_seconds <- function(x) {
 split_second_of_second <- function(x) {
   abs(split_seconds(x) - seconds(x))
 }
+
+decompose <- function(x) {
+  list(
+    sign = x < 0 & !is.na(x),
+    hours = abs(hours(x)),
+    minute_of_hour = minute_of_hour(x),
+    second_of_minute = second_of_minute(x),
+    split_seconds = split_second_of_second(x)
+  )
+}
